package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.TElectronicFenceService;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-09-14
 */
public interface ITElectronicFenceServiceService {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TElectronicFenceService selectTElectronicFenceServiceById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param tElectronicFenceService 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TElectronicFenceService> selectTElectronicFenceServiceList(TElectronicFenceService tElectronicFenceService);

    /**
     * 新增【请填写功能名称】
     *
     * @param tElectronicFenceService 【请填写功能名称】
     * @return 结果
     */
    public int insertTElectronicFenceService(TElectronicFenceService tElectronicFenceService);

    /**
     * 修改【请填写功能名称】
     *
     * @param tElectronicFenceService 【请填写功能名称】
     * @return 结果
     */
    public int updateTElectronicFenceService(TElectronicFenceService tElectronicFenceService);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTElectronicFenceServiceByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTElectronicFenceServiceById(Long id);

    /**
     * 获取这个Key下所有的服务
     *
     * @param keyId
     * @return
     */
    List<TElectronicFenceService> selectTElectronicFenceServiceByKeyId(Long keyId);

    /**
     * 获取一个可用服务
     *
     * @param keyId
     * @return
     */
    TElectronicFenceService selectAccessAvailableElectronicFenceServiceByKeyId(Long keyId);
}
